//!
//! Collection of basic algorithms for everyday development
//!

/// Binary search algorithm.
pub mod binary_search;
/// String-searching algorithms.
pub mod string;
/// Combinatorics algorithms
pub mod combinatorics;
/// Graph algorithms
pub mod graph;
/// Segment Tree
pub mod segment_tree;
/// Mathematics algorithms
pub mod math;
/// Trie or  prefix tree
pub mod trie;
/// Huffman Coding
pub mod huffman;
/// Bloom filter
pub mod bloom_filter;
/// Sparse table
pub mod sparse_table;
/// Binary Tree
pub mod binary_tree;